use strict;
use warnings;

package RPG;

# ABSTRACT:  This is merely a placeholder at this time.

1;

__END__

=pod

=head1 NAME

RPG - This is merely a placeholder at this time.

=head1 VERSION

version 0.502

=head1 AUTHOR

Peter L. Berghold <peter@berghold.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Peter L. Berghold.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
